# coding: utf-8

"""
    LINE Messaging API

    This document describes LINE Messaging API.  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic.v1 import BaseModel, Field, StrictStr, conlist

class GetAggregationUnitNameListResponse(BaseModel):
    """
    GetAggregationUnitNameListResponse
    https://developers.line.biz/en/reference/messaging-api/#get-name-list-of-units-used-this-month
    """
    custom_aggregation_units: conlist(StrictStr) = Field(..., alias="customAggregationUnits", description="An array of strings indicating the names of aggregation units used this month.")
    next: Optional[StrictStr] = Field(None, description="A continuation token to get the next array of unit names. Returned only when there are remaining aggregation units that weren't returned in customAggregationUnits in the original request.  ")

    __properties = ["customAggregationUnits", "next"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> GetAggregationUnitNameListResponse:
        """Create an instance of GetAggregationUnitNameListResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> GetAggregationUnitNameListResponse:
        """Create an instance of GetAggregationUnitNameListResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return GetAggregationUnitNameListResponse.parse_obj(obj)

        _obj = GetAggregationUnitNameListResponse.parse_obj({
            "custom_aggregation_units": obj.get("customAggregationUnits"),
            "next": obj.get("next")
        })
        return _obj

